%define anolis_release 1
# {_exec_prefix}/lib/kbd is correct even on x86_64.
# It is traditionally used for kdb data (console fonts, keymaps, ...).
# It is not used for any shared objects/executables.
%global kbd_datadir %{_exec_prefix}/lib/kbd

Name:           kbd
Version:        2.6.1
Release:        %{anolis_release}%{?dist}
Summary:        Tools for configuring the console (keyboard, virtual terminals, etc.)
License:        GPLv2+
URL:            http://www.kbd-project.org/

Source0: 	https://mirrors.edge.kernel.org/pub/linux/utils/kbd/%{name}-%{version}.tar.xz
Source1:        https://distro.ibiblio.org/openwall/Owl/pool/sources/kbd/kbd-latsun-fonts.tar.bz2
Source2: 	latarcyrheb-sun32.psfu
Source3:        xml2lst.pl
Source4:        cz-map.patch

BuildRequires:  gcc, bison, flex, gettext, pam-devel, check-devel, automake
BuildRequires:  console-setup, xkeyboard-config
Requires:       %{name}-misc = %{version}-%{release}
# Be sure that system is after UsrMove
Conflicts:      filesystem < 3
Provides:       vlock = %{version}
Conflicts:      vlock <= 1.3

%description
The %{name} package contains tools for managing a Linux
system's console's behavior, including the keyboard, the screen
fonts, the virtual terminals and font files.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package misc
Summary:        Data for kbd package
BuildArch:      noarch
 
%description misc
The %{name}-misc package contains data for kbd package - console fonts,
keymaps etc. Please note that %{name}-misc is not helpful without kbd.

%package legacy
Summary:        Legacy data for kbd package
BuildArch:      noarch
 
%description legacy
The %{name}-legacy package contains original keymaps for kbd package.
Please note that %{name}-legacy is not helpful without kbd.

%prep
%setup -q -a 1
cp -fp %{SOURCE2} data/consolefonts/
cp -fp %{SOURCE3} .
cp -fp %{SOURCE4} .

aclocal
autoconf

# 7-bit maps are obsolete; so are non-euro maps
pushd data/keymaps/i386
cp qwerty/pt-latin9.map qwerty/pt.map
cp qwerty/sv-latin1.map qwerty/se-latin1.map

mv azerty/fr.map azerty/fr-old.map
cp azerty/fr-latin9.map azerty/fr.map

cp azerty/fr-latin9.map azerty/fr-latin0.map # legacy alias

# Rename conflicting keymaps
mv fgGIod/trf.map fgGIod/trf-fgGIod.map
mv olpc/es.map olpc/es-olpc.map
mv olpc/pt.map olpc/pt-olpc.map
mv qwerty/cz.map qwerty/cz-qwerty.map
popd

# remove obsolete "gr" translation
pushd po
rm -f gr.po gr.gmo
popd

# Convert to utf-8
iconv -f iso-8859-1 -t utf-8 < "ChangeLog" > "ChangeLog_"
mv "ChangeLog_" "ChangeLog"

%build
%configure --prefix=%{_prefix} --datadir=%{kbd_datadir} --mandir=%{_mandir} --localedir=%{_datadir}/locale --enable-nls
%make_build

%install
%make_install

# ro_win.map.gz is useless
rm -f $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/i386/qwerty/ro_win.map.gz

# Create additional name for Serbian latin keyboard
ln -s sr-cy.map.gz $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/i386/qwerty/sr-latin.map.gz

# The rhpl keyboard layout table is indexed by kbd layout names, so we need a
# Korean keyboard
ln -s us.map.gz $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/i386/qwerty/ko.map.gz

# Some microoptimization
sed -i -e 's,\<kbd_mode\>,%{_bindir}/kbd_mode,g;s,\<setfont\>,%{_bindir}/setfont,g' \
        $RPM_BUILD_ROOT%{_bindir}/unicode_start

# Move original keymaps to legacy directory
mkdir -p $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/legacy
mv $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/{amiga,atari,i386,include,mac,ppc,sun} $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/legacy

# Convert X keyboard layouts to console keymaps
mkdir -p $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb
perl xml2lst.pl < /usr/share/X11/xkb/rules/base.xml > layouts-variants.lst
while read line; do
  XKBLAYOUT=`echo "$line" | cut -d " " -f 1`
  echo "$XKBLAYOUT" >> layouts-list.lst
  XKBVARIANT=`echo "$line" | cut -d " " -f 2`
  ckbcomp -rules base "$XKBLAYOUT" "$XKBVARIANT" | gzip > $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/"$XKBLAYOUT"-"$XKBVARIANT".map.gz
done < layouts-variants.lst

# Convert X keyboard layouts (plain, no variant)
cat layouts-list.lst | sort -u >> layouts-list-uniq.lst
while read line; do
  ckbcomp "$line" | gzip > $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/"$line".map.gz
done < layouts-list-uniq.lst

# wipe converted layouts which cannot input ASCII (#1031848)
zgrep -L "U+0041" $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/* | xargs rm -f

# Fix converted cz layout - add compose rules, if exists
if [ -f "$RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/cz.map.gz" ]; then
  gunzip $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/cz.map.gz
  patch $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/cz.map < %{SOURCE4}
  gzip $RPM_BUILD_ROOT%{kbd_datadir}/keymaps/xkb/cz.map
fi

%find_lang %{name}

%check
make check

%files -f %{name}.lang
%license COPYING
%doc docs/doc/font-formats/*.html docs/doc/utf/utf* docs/doc/dvorak/* docs/doc/kbd.FAQ*.html
%{_bindir}/*
%{_mandir}/*/*
%config(noreplace) %{_sysconfdir}/pam.d/vlock
# library used only for tests
%exclude %{_libdir}/libtswrap*
%exclude %{_prefix}/lib/debug/%{_libdir}/libtswrap*

%files doc
%doc ChangeLog AUTHORS README

%files misc
%{kbd_datadir}
%exclude %{kbd_datadir}/keymaps/legacy

%files legacy
%{kbd_datadir}/keymaps/legacy

%changelog
* Mon Feb 19 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.6.1-1
- update to 2.6.1

* Fri Dec 29 2023 happy_orange <songnannan@linux.alibaba.com> - 2.5.1-3
- fix the source error

* Thu Nov 16 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 2.5.1-2
- fix build error for kbd

* Mon Sep 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.5.1-1
- update to 2.5.1

* Mon Mar 28 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.4.0-3
- add xkb keymaps

* Mon Mar 28 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.4.0-2
- adds xkb and legacy keymaps subdirs to loadkyes search path
- unicode_start init from /etc/vconsole.conf

* Tue Mar  8 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 2.4.0-1
- Init version from upstream v2.4.0
